API for Albums
===============

.. module:: digikamdb.albums

The Albums Class
-----------------

.. autoclass:: Albums
    :members:

The Album Class (mapped)
-------------------------

.. autoclass:: _sqla.Album
    :members:

.. module:: digikamdb.albumroots

The AlbumRoots Class
----------------------

.. autoclass:: AlbumRoots
    :members:

The AlbumRoot Class (mapped)
------------------------------

.. autoclass:: _sqla.AlbumRoot
    :members:

Types of special properties
----------------------------

.. currentmodule:: digikamdb.types

.. autoclass::  AlbumRootStatus
    :members:
    :member-order:  bysource

.. autoclass::  AlbumRootType
    :members:
    :member-order:  bysource

